@@ -221,6 +221,19 @@ pin_newer_runtime_libs ()
 
     for line in "${output_array[@]}"
     do
+        case "$line" in
+            (*/*-linux-gnu/sse2/lib* | */*-linux-gnu/sse/lib* | */*-linux-gnu/i686/cmov/lib*)
+                debug "Library in hwcap directory: $line"
+                ;;
+            (*/*-linux-gnu/lib*)
+                debug "Library in base directory: $line"
+                ;;
+            (*)
+                debug "Skip library in subdirectory: $line"
+                continue
+                ;;
+        esac
+
         if [ "$zenity_progress" = true ]; then
             echo $(( ( 35 * n_done ) / find_num + 64 ))
         else
@@ -363,7 +376,7 @@ pin_newer_runtime_libs ()
 
         if [[ $runtime_version_newer == "yes" \
               || $runtime_version_newer == "forced" ]]; then
-            ln -s "$final_library" "$steam_runtime_path/pinned_libs_$bitness/$soname"
+            ln -fns "$final_library" "$steam_runtime_path/pinned_libs_$bitness/$soname"
             # Keep track of the exact version name we saw on the system at pinning time to check later
             >&2 echo "$host_soname_symlink" > "$steam_runtime_path/pinned_libs_$bitness/system_$soname"
             >&2 echo "$host_library" >> "$steam_runtime_path/pinned_libs_$bitness/system_$soname"
